@@ -54,7 +54,7 @@ def curve(
             curve_date = curve_dates[0]
         else:
             curve_date = curve_dates
-        q = limqueryutils.build_curve_query(scall, curve_date, column)
+        q = limqueryutils.build_curve_query({x:'FUTURES' for x in scall}, curve_date, column)
     res = query(q)
 
     if isinstance(symbols, dict):
@@ -143,7 +143,7 @@ def contracts(
     months: t.Optional[t.Tuple[str, ...]] = None,
     start_date: t.Optional[date] = None,
 ) -> pd.DataFrame:
-    matches = find_symbols_in_query(formula)
+    matches = tuple(find_symbols_in_query(formula).keys())
     contracts_list = get_symbol_contract_list(matches, monthly_contracts_only=True)
     contracts_list = limutils.filter_contracts(contracts_list, start_year=start_year, end_year=end_year, months=months)
 
@@ -226,15 +226,14 @@ def get_symbol_contract_list(
     return contracts_list
 
 
-def find_symbols_in_query(q: str) -> tuple:
+def find_symbols_in_query(q: str) -> dict:
     m = re.findall(r'\w[a-zA-Z0-9_.]+', q)
     if 'Show' in m:
         m.remove('Show')
     rel = relations(tuple(m)).T
     rel = rel[rel['type'].isin(['FUTURES', 'NORMAL'])]
     if len(rel) > 0:
-        return tuple(rel['name'])
-    return ()
+        return rel['type'].to_dict()
 
 
 if __name__ == '__main__':
